==> haskell-src-exts-util-0.2.3-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.3
id: haskell-src-exts-util-0.2.3-JvRwIxlnzecJK0N8S40Xob
key: haskell-src-exts-util-0.2.3-JvRwIxlnzecJK0N8S40Xob
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: 262d0eb4b454d871e5b4a66fd0da0e36
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-util-0.2.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-util-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haskell-src-exts-util-0.2.3
hs-libraries: HShaskell-src-exts-util-0.2.3-JvRwIxlnzecJK0N8S40Xob
depends:
    base-4.11.1.0 containers-0.5.11.0
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    haskell-src-exts-1.20.2-GZwGM0N2b0PEOuT1LwTZLH transformers-0.5.5.0
    uniplate-1.6.12-Gy31jayiIw68BwglcWhaMK
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             haskell-src-exts-1.20.2-GZwGM0N2b0PEOuT1LwTZLH=cf71cf535d85164f003912c9d17ec59c
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             uniplate-1.6.12-Gy31jayiIw68BwglcWhaMK=bf7a8e37e05d8b3020598df73b0c3939
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.3-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.3
id: haskell-src-exts-util-0.2.3-2xdnlzl2HdpK29QtrOdre0
key: haskell-src-exts-util-0.2.3-2xdnlzl2HdpK29QtrOdre0
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: e12cd951480fe91749ea926ba9bcffeb
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-util-0.2.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/haskell-src-exts-util-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/haskell-src-exts-util-0.2.3
hs-libraries: HShaskell-src-exts-util-0.2.3-2xdnlzl2HdpK29QtrOdre0
depends:
    base-4.11.1.0 containers-0.5.11.0
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
    haskell-src-exts-1.20.2-9SXcdQ64T9tDVOmt88tWTF transformers-0.5.5.0
    uniplate-1.6.12-Gy31jayiIw68BwglcWhaMK
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             haskell-src-exts-1.20.2-9SXcdQ64T9tDVOmt88tWTF=45fc7b9f2e0adbed483c09b299fc3510
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             uniplate-1.6.12-Gy31jayiIw68BwglcWhaMK=bf7a8e37e05d8b3020598df73b0c3939
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
